@@ -56,7 +56,7 @@ class RestAPI(object):
 				"email":True,
 			},
 		}
-
+		
 
 		"""
 		The plans.
@@ -402,7 +402,7 @@ class RestAPI(object):
 
 			# handle new data.
 			data = None
-			if True or response["error"] != None:
+			if response["error"] != None:
 				response = self.__save_new_user__(uid)
 				if response["error"] != None: 
 					if silent == False: print(f"Error: {response['error']}")
